# frozen_string_literal: true

module DvelpFlow
  module Channels
    class Voice < Base
      def communicate
        response.final? ? reply_and_connect : reply_and_gather
      end

      private

      def reply_and_connect
        voice_response.say(content) if content.present?

        enqueue_task
      end

      def enqueue_task
        voice_response.enqueue(enqueue_params) do |e|
          e.task task_attributes
        end.to_s
      end

      def enqueue_params
        {
          workflow_sid: params[:workflow_sid]
        }
      end

      def task_attributes
        {}
      end

      def reply_and_gather
        ::Twilio::TwiML::VoiceResponse.new do |r|
          r.gather(gather_attrs) do |g|
            g.say content
            g.pause length: ENV.fetch('TWILIO_GATHER_PAUSE', 0).to_i
          end

          r.redirect(params[:gathers_repeat_url], method: :post)
        end.to_s
      end

      def gather_attrs
        {
          action: params[:gathers_url],
          hints: ENV['ASR_HINTS'],
          input: 'speech',
          language: ENV['ASR_LANGUAGE'],
          method: 'POST',
          profanity_filter: true,
          speech_timeout: 'auto'
        }
      end

      def voice_response
        @voice_response ||= Twilio::TwiML::VoiceResponse.new
      end
    end
  end
end
