# frozen_string_literal: true

module DvelpFlow
  module DialogFlow
    class V2
      def initialize(access_token:, api_session_id:)
        self.access_token = access_token
        self.api_session_id = api_session_id
        self.api_version = api_version
      end

      def event_request(event)
        data = {
          query_input: {
            event: {
              name: event,
              language_code: ENV['APIAI_LANGUAGE']
            }
          }
        }

        call(data: data, endpoint: "sessions/#{api_session_id}:detectIntent")
      end

      def text_request(text)
        data = {
          query_input: {
            text: {
              text: text,
              language_code: ENV['APIAI_LANGUAGE']
            }
          }
        }

        call(data: data, endpoint: "sessions/#{api_session_id}:detectIntent")
      end

      private

      attr_accessor :access_token, :api_session_id, :api_version

      def call(data:, endpoint:)
        url = base_url + endpoint
        response = RestClient.post(url, data.to_json, headers)

        JSON.parse(response).deep_symbolize_keys!
      end

      def base_url
        "https://dialogflow.googleapis.com/v2beta1/projects/#{project}/agent/"
      end

      def project
        ENV['GCP_PROJECT_NAME']
      end

      def headers
        {
          accept: :json,
          authorization: "Bearer #{access_token}",
          content_type: :json
        }
      end
    end
  end
end
