# frozen_string_literal: true

module DvelpFlow
  module Responders
    class Base
      def initialize(params: {})
        self.content = params[:content]
        self.session_uuid = params[:session_uuid]
      end

      def to_s
        create_interaction
        intent_parser.speech
      end

      def final?
        !intent_parser.parameters.include? :continue
      end

      def content_chain
        DvelpFlow.cache.read("contents/#{session_uuid}") || []
      end

      private

      attr_accessor :content, :session_uuid

      def create_interaction
        DvelpFlow.cache.write(
          "contents/#{session_uuid}",
          content_chain << content,
          expires_in: 5.minutes
        )
      end

      def intent_parser
        klass = Object.const_get(
          "::DvelpFlow::Parsers::V#{DialogFlow::VERSION}"
        )
        @intent_parser ||= klass.new(
          response: api_intent_response
        )
      end

      def api_intent_response
        intent_ai_client.text_request(content)
      end

      def intent_ai_client
        @intent_ai_client ||= DvelpFlow::DialogFlow::Client.init(
          access_token: DvelpFlow::Google::Auth::Token.fetch!,
          api_session_id: session_uuid
        )
      end
    end
  end
end
